Functions working with specomatic field definitions.
Functions working with specomatic field definitions.
Given field field and field definition field-def
returns a map of defaults for the field definition.
Given field `field` and field definition `field-def` returns a map of defaults for the field definition.
(dispatch field-def)Given the field definition field-def, returns the dispatch value.
Given the field definition `field-def`, returns the dispatch value.
Given entity type etype, field and field definition field-def,
returns a tuple of entity type, inverse field and field definition
or nil if none can be inferred.
Given entity type `etype`, `field` and field definition `field-def`, returns a tuple of entity type, inverse field and field definition or nil if none can be inferred.
(inverse-of field-def)Given the field definition field-def, returns the inverse field.
Given the field definition `field-def`, returns the inverse field.
(inverse? field-def)Checks if field definition field-def is inverse.
Checks if field definition `field-def` is inverse.
(kind field-def)Given the field definition field-def, returns the kind.
Given the field definition `field-def`, returns the kind.
Checks if the field definition field-def is a reference collection.
Checks if the field definition `field-def` is a reference collection.
(reference-type field-def)Given the field definition field-def, returns the reference type.
Given the field definition `field-def`, returns the reference type.
Checks if the field definition field-def is a reference.
Checks if the field definition `field-def` is a reference.
Checks if the field definition field-def is relational.
Checks if the field definition `field-def` is relational.
(target field-def)Given the field definition field-def, returns the target entity type.
Given the field definition `field-def`, returns the target entity type.
(via field-def)Given the reference field definition field-def, returns the reference field on the opposite side of the relation, if available.
Given the reference field definition `field-def`, returns the reference field on the opposite side of the relation, if available.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |